==> tcpview_2.0.orig.tar.gz: tcpview-2.0.0.10/translations/language_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>TcpView</source>
        <translation>TcpView</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Include word - |
word1|word2|word3

Word Boundaries - \b
\bWord     - start  with Word
Word\b     - end with Word
\bWord\b - whole words only 

Example. Only UDP and TCP (not TCP6 ot UDP6)
tcp\b|udp\b</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Stops loading records</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Do not cleanup deleted records</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Copy to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="146"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>Save to XML or CVS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="162"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>Display program names (Password required)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>WHOIS - Lookup service to search for the domain name registration information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>whois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>  %1 / %2  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source> Visible %1 / Total %2 </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Cannot start module, because 
%1
 is missing or execution access is denied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>Run as root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>Failed on start
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>Failed on &apos;init&apos; client module</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="143"/>
        <source>Failed on showEvent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Copy row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="46"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="46"/>
        <location filename="../source/cconnectionstree.cpp" line="65"/>
        <source>tcp6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="47"/>
        <source>Local Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="48"/>
        <source>Local Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="48"/>
        <location filename="../source/cconnectionstree.cpp" line="52"/>
        <source>255.255.255.255</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="49"/>
        <source>Local Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="49"/>
        <location filename="../source/cconnectionstree.cpp" line="53"/>
        <source>65535</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="50"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="50"/>
        <source>ESTABLISHED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="51"/>
        <source>Remote Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="52"/>
        <source>Remote Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="53"/>
        <source>Remote Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="54"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="54"/>
        <location filename="../source/cconnectionstree.cpp" line="55"/>
        <source>0000000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="55"/>
        <source>Inode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="56"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="56"/>
        <source>2017-01-01 00:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="57"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="58"/>
        <source>RowId</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="63"/>
        <source>tcp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="64"/>
        <source>udp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="66"/>
        <source>udp6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="67"/>
        <source>raw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="68"/>
        <source>raw6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="74"/>
        <source>established</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="75"/>
        <source>syn_sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="76"/>
        <source>syn_recv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="77"/>
        <source>fin_wait1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="78"/>
        <source>fin_wait2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="79"/>
        <source>time_wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="80"/>
        <source>unconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="81"/>
        <source>close_wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="82"/>
        <source>last_ack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="83"/>
        <source>listen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="84"/>
        <source>closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="85"/>
        <source>closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="86"/>
        <source>removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="242"/>
        <source>Save as ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="281"/>
        <location filename="../source/cconnectionstree.cpp" line="285"/>
        <location filename="../source/cfilesavewrapper.cpp" line="44"/>
        <location filename="../source/cfilesavewrapper.cpp" line="84"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="285"/>
        <source>Unexpected exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cfilesavewrapper.h" line="27"/>
        <source>Error: Cannot write file
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/clanguage.cpp" line="117"/>
        <location filename="../source/clanguage.cpp" line="122"/>
        <source>English</source>
        <translation>Français</translation>
    </message>
</context>
</TS>

==> tcpview_3.4.0.orig.tar.gz: tcpview-3.4.0/translations/language_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="20"/>
        <source>&lt;html&gt;
&lt;head/&gt;
&lt;body&gt;
Copyright (C) chipmunk-sm&lt;br&gt;
&lt;a href=&quot;https://github.com/chipmunk-sm/&quot;&gt;https://github.com/chipmunk-sm/&lt;/a&gt;
&lt;/body&gt;
&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="36"/>
        <source>Color settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/configdialog.cpp" line="56"/>
        <source>Foreground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/configdialog.cpp" line="61"/>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/configdialog.cpp" line="71"/>
        <source>Reset color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/configdialog.cpp" line="86"/>
        <source>Color - B &amp;&amp; W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/configdialog.cpp" line="93"/>
        <source>Color - W &amp;&amp; B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/configdialog.cpp" line="108"/>
        <source>Table - set background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/configdialog.cpp" line="115"/>
        <source>Table - set default background</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>Stop reading new records</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="162"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Do not cleanup deleted records</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Copy to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Include word - |
word1|word2|word3

Word Boundaries - \b
\bWord     - start  with Word
Word\b     - end with Word
\bWord\b - whole words only

Example. Only UDP and TCP (not TCP6 ot UDP6)
tcp\b|udp\b</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.ui" line="146"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Save to XML or CVS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <source>&lt;a href=&quot;https://github.com/chipmunk-sm/tcpview&quot;&gt;https://github.com/chipmunk-sm/tcpview&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Display the path of the executable process.  (Password required)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <source>Show processes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>WHOIS - Lookup service to search for the domain name registration information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>whois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Visible %1 / total %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Cannot start module, because 
%1
 is missing or execution access is denied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="488"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Run as root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>Command &apos;whois&apos; not found,
but can be installed with:
sudo apt install whois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Failed run &apos;whois&apos;:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>Copy row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>Restart?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Root module not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="45"/>
        <source>Protocol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="45"/>
        <location filename="../source/cconnectionstree.cpp" line="63"/>
        <source>tcp6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="46"/>
        <source>Local Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="47"/>
        <source>Local Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="47"/>
        <location filename="../source/cconnectionstree.cpp" line="51"/>
        <source>255.255.255.255</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="48"/>
        <source>Local Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="48"/>
        <location filename="../source/cconnectionstree.cpp" line="52"/>
        <source>65535</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="49"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="49"/>
        <source>ESTABLISHED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="50"/>
        <source>Remote Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="51"/>
        <source>Remote Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="52"/>
        <source>Remote Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="53"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="53"/>
        <location filename="../source/cconnectionstree.cpp" line="54"/>
        <source>0000000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="54"/>
        <source>Inode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="55"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="55"/>
        <source>2017-01-01 00:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="56"/>
        <source>Process path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="61"/>
        <source>tcp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="62"/>
        <source>udp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="64"/>
        <source>udp6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="65"/>
        <source>raw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="66"/>
        <source>raw6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="68"/>
        <source>established</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="69"/>
        <source>syn_sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="70"/>
        <source>syn_recv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="71"/>
        <source>fin_wait1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="72"/>
        <source>fin_wait2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="73"/>
        <source>time_wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="74"/>
        <source>unconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="75"/>
        <source>close_wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="76"/>
        <source>last_ack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="77"/>
        <source>listen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="78"/>
        <source>closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="79"/>
        <source>closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/connectionstatehelper.cpp" line="80"/>
        <source>removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="208"/>
        <source>Save as ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cconnectionstree.cpp" line="247"/>
        <location filename="../source/cconnectionstree.cpp" line="251"/>
        <location filename="../source/cfilesavewrapper.cpp" line="44"/>
        <location filename="../source/cfilesavewrapper.cpp" line="84"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../source/cconnectionstree.cpp" line="251"/>
        <source>Unexpected exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/cfilesavewrapper.cpp" line="43"/>
        <location filename="../source/cfilesavewrapper.cpp" line="83"/>
        <source>Error: Cannot write file
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../source/clanguage.cpp" line="108"/>
        <location filename="../source/clanguage.cpp" line="113"/>
        <source>English</source>
        <translation>Français</translation>
    </message>
</context>
</TS>
